# serial_monitor

![logo](https://raw.githubusercontent.com/mbridak/serial_monitor/master/logo.png)

Monitors connect/disconnects changes in USB serial devices.
Pops up a notification on the Gnome desktop.

![snapshot of notification](https://raw.githubusercontent.com/mbridak/serial_monitor/master/Screenshot.png)

## Accreditation

I totally stole this from @joshburnett [COM-Port-Monitor](https://github.com/joshburnett/COM-Port-Monitor).
Which does the same but for Windows with Qt.

## Install

pip install serial_monitor

## Usage

```bash
serial_monitor
```
